/*
ScheduleTogether Frontend
Copyright (C) 2024, Zervó Zadachin

DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License version 3
as published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License version 3 for more details.

This program is built in two major frameworks, and incorporates external libraries for certain functionalities.
These frameworks and libraries are covered by their respective licenses, and their usage
agreements are as outlined in their respective documentation or source
code.

This program uses assets and resources provided by third parties, and are likely not covered by this copyright notice. 
See their respective directories and relevant notices.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

const configUrl = `${window.location.origin}/config.json`; // Get the base URL dynamically

let apiUrl: string | null = null;

export const getApiUrl = (): string => {
    if (apiUrl) {
        // If the API URL has already been fetched, return it immediately
        return apiUrl;
    }

    try {
        const xhr = new XMLHttpRequest();
        xhr.open('GET', configUrl, false); // Synchronous XHR request
        xhr.send();

        if (xhr.status !== 200) {
            throw new Error(`Network response was not ok: ${xhr.status}`);
        }

        const configData = JSON.parse(xhr.responseText);
        apiUrl = configData.apiUrl; // Extract the API URL
        return apiUrl || "";
    } catch (error) {
        throw error;
    }
}

// Call the function to initialize the apiUrl
getApiUrl();