/*
ScheduleTogether Frontend
Copyright (C) 2024, Zervó Zadachin

DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License version 3
as published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License version 3 for more details.

This program is built in two major frameworks, and incorporates external libraries for certain functionalities.
These frameworks and libraries are covered by their respective licenses, and their usage
agreements are as outlined in their respective documentation or source
code.

This program uses assets and resources provided by third parties, and are likely not covered by this copyright notice. 
See their respective directories and relevant notices.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

import { defineStore } from 'pinia'
import type { Auth, DetailedUser } from '@/types'
import { fetchWrapper } from '@/helpers/fetch-wrapper'
import { getApiUrl } from '@/helpers/config-loader';
import { useAlertStore } from './alert';

export const useAuthStore = defineStore('auth', {
  state: () => ({
    auth: JSON.parse(localStorage.getItem('auth') || "{}") as Auth,
    user: JSON.parse(localStorage.getItem('this_user') || "{}") as DetailedUser,
  }),
  actions: {
    async login(username: string, password: string) {
      try {
        const data = await fetchWrapper.post(`${getApiUrl()}/account/signin`, { username, password})
        const token: string = data.token || ""

        if (token == null) {
          throw new Error("Could not sign in, didn't receive token");
        }

        this.auth = {
          token 
        }

        const user: DetailedUser = await fetchWrapper.get(`${getApiUrl()}/users/self`);
        this.user = user;

        localStorage.setItem('this_user', JSON.stringify(user));
      } catch (error) {
        const alertStore = useAlertStore();
        alertStore.error((error as Error).message, 5000);
      }
    }
  }
})
